#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05
#
# (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# @# loader.sh 22.0.5.0.0 09/02/13 14:38:11 
# @# 


############################################################################
# NB!!!!
# Because we're usually run via the sentry, it's important not to resource
# the .prospectrc file, as some variables may have been redefined from
# arguments passed to the sentry startup script sentry.sh.
############################################################################

# We need to augment the loader's argument list with the data-gateway we use
#WRITETOFILE=-wtf

STARTING_DIR=`pwd`

#Function to clean-up temporary directories if we abort
cleanup() {
  if [ -d $TARGET_DIR ]
  then
    rm -rf $TARGET_DIR
  fi
}

PRELOADPROC=$PROSPECT_HOME/MotoEVDO_loader/EVDO_PM/scripts/preparse.pl

while [ $# -gt 0 ]
do
case $1 in
    -filename)
            shift

            if ! test -s $1
	      then
	        echo "ERROR: $FILENAME not of valid file size."
	        echo "Reason: $FILENAME must be greater than 0 size."
	        exit 1
	    fi

            export FILENAME=$1
	    DIRNAME=`dirname $1`
            BASENAME=`basename $1`
	    FILEMAIN=${FILENAME%.*}
	    FILEEXT=${FILENAME##*.}

	    echo "FILENAME->"$FILENAME
	    echo "FILEMAIN->"$FILEMAIN
	    echo "FILEEXT->" $FILEEXT

            TOKENS=`echo $BASENAME | tr '.' ' '`
            NUM_TOKENS=`echo $TOKENS | wc -w`

            if [ $NUM_TOKENS -ne 6 ] && [ $NUM_TOKENS -ne 5 ]
            then
              echo "Error: $FILENAME not in supported Motorola EVDO PM Data filename format."
              echo "Reason: $FILENAME should have either 5 (R6.1) or 6 (R4, R5, R6, R7, R8, R9, R10) fields."
              exit 1
            fi

	    RELNO=`echo $FILENAME | cut -d / -f5 | cut -c 2-`
	    REL=R$RELNO
            INPUT_DIR=$PROSPECT_HOME/../ftpIN/MotoEVDO/$REL/in
	    FMTVER="#FORMAT $RELNO"
          ;;
    -tableLoadId)
            shift
            case $1 in
              TLID_EVDO_PM)
                  DG_FILE=$PROSPECT_HOME/MotoEVDO_loader/EVDO_PM/GATEWAY/dataGateway.hdd
                  ;;
                TLID_EVDO_PM_R61)
                  DG_FILE=$PROSPECT_HOME/MotoEVDO_loader/EVDO_PM/GATEWAY/dataGateway.hdd
                  ;;
              *)
                  echo "$0: Unknown -tableLoadId $1"
                  exit 1
                  ;;
            esac
            ARGS="$ARGS -tableLoadId $1 -dg $DG_FILE"
        ;;
# Ignore the -dg parameters and skip it's contents
    -dg)
            shift
        ;;
    *)
        ARGS="$ARGS $1"
        ;;
esac
shift
done
echo $ARGS

echo $FILENAME | grep ".tgz"

FILE_TYPE=`basename ${FILENAME}| cut -d"." -f3 | cut -c1-5`

NENAME=`basename ${FILENAME}|sed 's/[.].*$//'`
FTSTAMP=`basename ${FILENAME}| cut -d"." -f4 | cut -c1-12`
integer SYSTEM_ID=`awk '$1=="'${NENAME}'" {print $2}' ${PROSPECT_HOME}/ne_list`

if ( [ $REL = "R6.1" ] || [ $REL = "R7" ] || [ $REL = "R8" ] || [ $REL = "R9" ] || [ $REL = "R10" ] ) && [ $FILE_TYPE != "BSCDO" ]
then
	NEID=`basename ${FILENAME} |cut -d"." -f2 | sed s/^EMH//g | cut -d"O" -f2`
else
	NEID=`basename ${FILENAME}|cut -d"." -f3|cut -d"O" -f2|cut -d"_" -f2`
fi

NE_ID=`
   sqlplus -s ${DB_CONNECT} <<!
   set heading off
   set timing off
   set time off
   set feedback off
   select to_number(${NEID}) from dual;
!
`
NE_ID=`echo ${NE_ID}|sed -e 's#[\t\n ]##g'`
NE_KEY=$SYSTEM_ID-$NE_ID

if [ $FILEEXT = "tgz" ]
then

#   echo ${PMDEPENDPROGRAM} -service ${PM_PORT}@${WM_SERVER} \
#                        -d ${NE_KEY} -file ${FILENAME} 
   ${PMDEPENDPROGRAM} -service ${PM_PORT}@${WM_SERVER} \
                        -d ${NE_KEY} -file ${FILENAME} & 

   cd $INPUT_DIR
   # Creation of temporary directory for processing of file
   work_dir="`date '+20%y%m%d-%H:%M:%S'`".$$

   if [ -d $work_dir ]
   then
      echo "ERROR: $work_dir should have been removed under $INPUT_DIR from previous data loading!  Anyway, deleting it now."
      rm -rf $work_dir
   fi

   mkdir $work_dir

   TARGET_DIR=$INPUT_DIR/$work_dir

   # Move into working directory and uncompress data file
   FILENAME1=`basename $FILENAME`
   
   echo "FILENAME1->"$FILENAME1
   cp $FILENAME1 $work_dir
   cd $work_dir
   gunzip $FILENAME1

   # Expand data archive
   for file in `ls *.tar 2>/dev/null`
   do
       tar xf $file >/dev/null
       if [ $? -ne 0 ]
       then
           echo "Could not expand raw data archive: $file"
       else
           chmod u+rwx *
           rm -f $file >/dev/null
       fi
   done
   RET_CODE=$?
   
   cd CSV

   DIRTOK=`ls`
   FILE1=`echo $DIRTOK | cut -d ' ' -f1`
   FILE2=`echo $DIRTOK | cut -d ' ' -f2`
   EXIT_CODE=1

   #Check Whether the Input File contains "#FORMAT 4" or #FORMAT 5" or "#FORMAT 6" or 
   # "#FORMAT 6.1" or "#FORMAT 7" or "#FORMAT 6B" or "#FORMAT 8" or "#FORMAT 9" or 
   # "#FORMAT 8.1" or "#FORMAT 8B" or "#FORMAT 9.1" or "#FORMAT 9B"
   for dir in `ls`
     do
       cd $dir
       for file in `ls *.csv`
         do
	   PREFIXCHK=`echo $file | cut -c -6`
           FMTCHK=`egrep "#FORMAT 4|#FORMAT 5|#FORMAT 6|#FORMAT 6.1|#FORMAT 7|#FORMAT 6B|#FORMAT 7B|#FORMAT 7.1|#FORMAT 8|#FORMAT 8.1|#FORMAT 8B|#FORMAT 9|#FORMAT 9.1|#FORMAT 9B|#FORMAT 10|" $file | cut -d"," -f1 | head -1`
           if [ "$FMTCHK" == "#FORMAT 4" ] 
	   then
             echo "Warning: R4 EVDO PM Data File is no longer supported."
	     echo "Reason: EVDO R4 (#FORMAT 4) Data File is no longer supported."
             echo "Discarding $file."
             #rm -f $file
             cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
           elif [ "$FMTCHK" != "#FORMAT 5" ] && [ "$FMTCHK" != "#FORMAT 6" ] && [ "$FMTCHK" != "#FORMAT 6.1" ] && [ "$FMTCHK" != "#FORMAT 6B" ] && [ "$FMTCHK" != "#FORMAT 7" ] && [ "$FMTCHK" != "#FORMAT 7B" ] && [ "$FMTCHK" != "#FORMAT 7.1" ] && [ "$FMTCHK" != "#FORMAT 8" ] && [ "$FMTCHK" != "#FORMAT 8B" ] && [ "$FMTCHK" != "#FORMAT 8.1" ] && [ "$FMTCHK" != "#FORMAT 9" ] && [ "$FMTCHK" != "#FORMAT 9B" ] && [ "$FMTCHK" != "#FORMAT 9.1" ] && [ "$FMTCHK" != "#FORMAT 10" ]
           then
             echo "Warning: $file not a valid Motorola EVDO PM Data File."
             echo "Reason: Data File does not contain #FORMAT 5 or #FORMAT 6/6.1/6B or #FORMAT 7/7B/7.1 or #FORMAT 8/8.1/8B or #FORMAT 9/9.1/9B or #FORMAT 10 in the first line."
             echo "Discarding $file."
             #rm -f $file
	     cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
	   ### This is for R5 checking. R5 only loads #FORMAT 5 files.
	   elif [ "$FMTVER" == "#FORMAT 5" ] && [ "$FMTCHK" != "#FORMAT 5" ]
	   then
	     echo "Warning: $file loaded in wrong ftpIN directory"
	     echo "Reason: Crossloading of Data are not supported, R5 ftpIN only loads #FORMAT 5 files"
	     echo "Discarding $file."
	     #rm -f $file
	     cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
	   ### This is for R6 checking. R6 only loads #FORMAT 6 and #FORMAT 6B files.
	   elif [ "$FMTVER" == "#FORMAT 6" ] && [ "$FMTCHK" != "#FORMAT 6" ] && [ "$FMTCHK" != "#FORMAT 6B" ]
	   then
	     echo "Warning: $file loaded in wrong ftpIN directory"
	     echo "Reason: Crossloading of Data are not supported, R6 ftpIN only loads #FORMAT 6 or #FORMAT 6B files"
	     echo "Discarding $file."
	     #rm -f $file
	     cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
	   ### This is for R6.1 checking. R6.1 only loads #FORMAT 6.1 for STS_BS files.
	   elif [ "$FMTVER" == "#FORMAT 6.1" ] && [ "$PREFIXCHK" == "STS_BS" ] && [ "$FMTCHK" != "#FORMAT 6.1" ]
	   then
	     echo "Warning: $file loaded in wrong ftpIN directory"
	     echo "Reason: Crossloading of Data are not supported, R6.1 ftpIN only loads #FORMAT 6.1 STS_BS files"
	     echo "Discarding $file."
	     #rm -f $file	 
	     cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
	   ### This is for R6.1 checking. R6.1 only loads #FORMAT 6 or #FORMAT 6.1 for STS_MC files.
	   elif [ "$FMTVER" == "#FORMAT 6.1" ] && [ "$PREFIXCHK" == "STS_MC" ] && [ "$FMTCHK" != "#FORMAT 6" ] && [ "$FMTCHK" != "#FORMAT 6.1" ]
	   then
	     echo "Warning: $file loaded in wrong ftpIN directory"
	     echo "Reason: Crossloading of Data are not supported, R6.1 ftpIN only loads #FORMAT 6 or #FORMAT 6.1 STS_MC files"
	     echo "Discarding $file."
	     #rm -f $file
	     cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
           ### This is for R7 checking. R7 only loads #FORMAT 7 for STS_BS files.
	   elif [ "$FMTVER" == "#FORMAT 7" ] && [ "$PREFIXCHK" == "STS_BS" ] && [ "$FMTCHK" != "#FORMAT 7" ] && [ "$FMTCHK" != "#FORMAT 7B" ] && [ "$FMTCHK" != "#FORMAT 7.1" ]
	   then
             echo "Warning: $file loaded in wrong ftpIN directory"
	     echo "Reason: Crossloading of Data are not supported, R7 ftpIN only loads #FORMAT 7 STS_BS files"
	     echo "Discarding $file."
	     #rm -f $file	 
	     cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
	   ### This is for R7 checking. R7 only loads #FORMAT 6.1 or #FORMAT 7 for STS_MC files.
	   elif [ "$FMTVER" == "#FORMAT 7" ] && [ "$PREFIXCHK" == "STS_MC" ] && [ "$FMTCHK" != "#FORMAT 6.1" ] && [ "$FMTCHK" != "#FORMAT 7" ] && [ "$FMTCHK" != "#FORMAT 7B" ] && [ "$FMTCHK" != "#FORMAT 7.1" ]
	   then
	     echo "Warning: $file loaded in wrong ftpIN directory"
	     echo "Reason: Crossloading of Data are not supported, R7 ftpIN only loads #FORMAT 6.1 or #FORMAT 7 STS_MC files"
	     echo "Discarding $file."
	     #rm -f $file
	     cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE

           ### This is for R8 checking. R8 only loads #FORMAT 8 for STS_BS files.
	   elif [ "$FMTVER" == "#FORMAT 8" ] && [ "$PREFIXCHK" == "STS_BS" ] && [ "$FMTCHK" != "#FORMAT 8" ] && [ "$FMTCHK" != "#FORMAT 8B" ] && [ "$FMTCHK" != "#FORMAT 8.1" ]
	   then
             echo "Warning: $file loaded in wrong ftpIN directory"
	     echo "Reason: Crossloading of Data are not supported, R8 ftpIN only loads #FORMAT 8/8B/8.1 STS_BS files"
	     echo "Discarding $file."
	     #rm -f $file	 
	     cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
	   ### This if for R8 checking. R8 only loads #FORMAT 6.1 or #FORMAT 8 for STS_MC files.
	   elif [ "$FMTVER" == "#FORMAT 8" ] && [ "$PREFIXCHK" == "STS_MC" ] && [ "$FMTCHK" != "#FORMAT 7" ] && [ "$FMTCHK" != "#FORMAT 8" ] && [ "$FMTCHK" != "#FORMAT 8B" ] && [ "$FMTCHK" != "#FORMAT 8.1" ]
	   then
	     echo "Warning: $file loaded in wrong ftpIN directory"
	     echo "Reason: Crossloading of Data are not supported, R8 ftpIN only loads #FORMAT 7 or #FORMAT 8/8B/8.1 STS_MC files"
	     echo "Discarding $file."
	     #rm -f $file
	     cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
	   ### This is for R9 checking. R9 only loads #FORMAT 9 for STS_BS files.
           elif [ "$FMTVER" == "#FORMAT 9" ] && [ "$PREFIXCHK" == "STS_BS" ] && [ "$FMTCHK" != "#FORMAT 9" ] && [ "$FMTCHK" != "#FORMAT 9B" ]  && [ "$FMTCHK" != "#FORMAT 9.1" ]
           then
             echo "Warning: $file loaded in wrong ftpIN directory"
             echo "Reason: Crossloading of Data are not supported, R9 ftpIN only loads #FORMAT 9/9B/9.1 STS_BS files"
             echo "Discarding $file."
             #rm -f $file
             cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
           ### This is for R9 checking. R9 only loads #FORMAT 8 or #FORMAT 9 for STS_MC files.
           elif [ "$FMTVER" == "#FORMAT 9" ] && [ "$PREFIXCHK" == "STS_MC" ] && [ "$FMTCHK" != "#FORMAT 8" ] && [ "$FMTCHK" != "#FORMAT 8B" ] && [ "$FMTCHK" != "#FORMAT 8.1" ] && [ "$FMTCHK" != "#FORMAT 9" ] && [ "$FMTCHK" != "#FORMAT 9B" ] && [ "$FMTCHK" != "#FORMAT 9.1" ]
           then
             echo "Warning: $file loaded in wrong ftpIN directory"
             echo "Reason: Crossloading of Data are not supported, R9 ftpIN only loads #FORMAT 8 or #FORMAT 9 STS_MC files"
             echo "Discarding $file."
             #rm -f $file
             cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
	   ### This is for R10 checking. R10 only loads #FORMAT 10 for STS_BS files.
           elif [ "$FMTVER" == "#FORMAT 10" ] && [ "$PREFIXCHK" == "STS_BS" ] && [ "$FMTCHK" != "#FORMAT 10" ]   
	   then
             echo "Warning: $file loaded in wrong ftpIN directory"
             echo "Reason: Crossloading of Data are not supported, R10 ftpIN only loads #FORMAT 10 STS_BS files"
             echo "Discarding $file."
             #rm -f $file
             cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
           ### This is for R10 checking. R10 only loads #FORMAT 8 or #FORMAT 10 for STS_MC files.
  elif [ "$FMTVER" == "#FORMAT 10" ] && [ "$PREFIXCHK" == "STS_MC" ] && [ "$FMTCHK" != "#FORMAT 9" ] && [ "$FMTCHK" != "#FORMAT 9B" ] && [ "$FMTCHK" != "#FORMAT 9.1" ] && [ "$FMTCHK" != "#FORMAT 10" ]
           then
             echo "Warning: $file loaded in wrong ftpIN directory"
             echo "Reason: Crossloading of Data are not supported, R10 ftpIN only loads #FORMAT 9 or #FORMAT 10 STS_MC files"
             echo "Discarding $file."
             #rm -f $file
             cd $INPUT_DIR
             rm -rf $work_dir
             exit $EXIT_CODE
           else
             #Check if the collection period is 5 minutes
             integer STARTMIN=`grep ",[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]" $file | head -1 | cut -d"," -f4 | cut -c11-12`
             integer ENDMIN=`grep ",[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]" $file | head -1 | cut -d"," -f5 | cut -c11-12`

             INTERVAL=`expr $ENDMIN - $STARTMIN`

             if [ $INTERVAL -ne 5 ] && [ $INTERVAL -ne -55 ]
             then
               echo "Warning: $file not a valid Motorola EVDO PM Data File."
               echo "Reason: Motorola EVDO PM collection period is not 5 minutes."
               echo "Discarding $file."
               rm -f $file
             else 
	       # Add "Collection Period" info to the file
               COLLPER="#\"Collection Period (min)\",\"5\""
               echo $COLLPER > $file.tmp
               # Add fileprefix STS_BS or STS_MC to the file
               echo "#"$PREFIXCHK >> $file.tmp
               cat $file >> $file.tmp
               mv $file.tmp $file
               EXIT_CODE=0
             fi
           fi
         done
         cd ..
     done

     FILEMAIN1=${FILENAME1%.*}
     echo "FILEMAIN1->"$FILEMAIN1

     if [ $EXIT_CODE -eq 0 ]
     then
       cat $FILE1/* $FILE2/* > $FILEMAIN1 2>/dev/null
       #gzip $FILEMAIN1
       #cp *.gz $INPUT_DIR

	# Invoke loader for .tgz
	cd $STARTING_DIR
	echo "SYSTEMNAME,$SYSTEM_ID\nNEID,$NE_ID`cat $INPUT_DIR/$work_dir/CSV/$FILEMAIN1`"  | ${PRELOADPROC} | ${LOADERPROGRAM} ${CONFIGSET} ${WMPM} -pipeFile $FILENAME ${ARGS} ${SILENTPARSE} ${WRITETOFILE} -suppress PKN -suppress DPK
	EXIT_CODE=$?
     fi
       # Remove the temporary working directory
       cd $INPUT_DIR
       rm -rf $work_dir
       exit $EXIT_CODE 
else

  echo "Error: $FILENAME not in valid Motorola EVDO PM Data File format."
  echo "Reason: $FILENAME should be in .tgz format."
  exit 1

fi
